@@ -1,11 +1,11 @@
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Callable, Dict, Iterable, Mapping, Optional, Sequence, TypeVar, Tuple
+from typing import Any, Callable, Dict, Iterable, Mapping, Optional, Sequence, Tuple, TypeVar
 
-from tqdm import tqdm  # type: ignore
+import cattrs
+import countergen.config
 import openai
-
-from countergen.config import OPENAI_API_BASE, OPENAI_API_KEY
+from tqdm import tqdm  # type: ignore
 
 T = TypeVar("T")
 
@@ -20,10 +20,6 @@ def other(t: Tuple[T, T], x: T) -> T:
     return t[0]
 
 
-def unwrap_or(maybe: Optional[T], default: T) -> T:
-    return default if maybe is None else maybe
-
-
 def all_same(l: Sequence[Any]) -> bool:
     return all(x == l[0] for x in l[1:])
 
@@ -41,15 +37,14 @@ def estimate_paraphrase_length(text: str):
     return len(text) // average_token_length + safety_margin
 
 
-def set_and_check_oai_key(key: Optional[str] = OPENAI_API_KEY, base: str = OPENAI_API_BASE):
-    """Set the key (and the base) of the openai api.
+class FromAndToJson:
+    """Add a from_json_dict & to_json_dict functions.
 
-    Default arguments are the ones from the config.
+    The class is expected to be created using @attrs.define."""
 
-    Checks that the key is not None."""
-    if key is None:
-        raise RuntimeError(
-            "Please provide openai key to use its api! Use `countergen.config.OPENAI_API_KEY = YOUR_KEY`"
-        )
-    openai.api_key = key
-    openai.api_base = base
+    @classmethod
+    def from_json_dict(cls, json_dict: Mapping[str, Any]):
+        return cattrs.structure(json_dict, cls)
+
+    def to_json_dict(self) -> Mapping[str, Any]:
+        return cattrs.unstructure(self, self.__class__)
