@@ -1,5 +1,4 @@
 import abc
-from this import d
 from typing import (
     Callable,
     Generic,
@@ -14,6 +13,9 @@ from typing import (
     Tuple,
 )
 
+from attrs import define
+from countergen.tools.utils import FromAndToJson
+
 Input = str  # The input to an NLP mode
 Outputs = List[str]  # The different acceptable outputs of the NLP, string label or number, but in string format
 
@@ -59,7 +61,8 @@ class Paraphraser(Augmenter):
         return ()
 
 
-class Variation(NamedTuple):
+@define
+class Variation(FromAndToJson):
     """An input associated with the different categories it belongs to."""
 
     text: Input
@@ -107,11 +110,11 @@ class StatsAggregator(Generic[Aggregate], metaclass=abc.ABCMeta):
 
     def save_aggregation(self, aggregate: Aggregate, file: Optional[TextIO] = None):
         """Save the aggregate to a file."""
-        raise NotImplementedError(f"{__class__.__name__} can't save aggregates.")
+        raise NotImplementedError(f"{self.__class__.__name__} can't save aggregates.")
 
     def load_aggregation(self, file: TextIO) -> Aggregate:
         """Load the aggregate from a file."""
-        raise NotImplementedError(f"{__class__.__name__} can't load aggregates.")
+        raise NotImplementedError(f"{self.__class__.__name__} can't load aggregates.")
 
     def display(self, aggregates: Mapping[str, Aggregate]):
         """Display and compare the aggregates of different models/datasets.
